##
##  monit.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         monit
Summary:      Service Monitoring Daemon
URL:          http://mmonit.com/monit/
Vendor:       Jan-Henrik Haukeland et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Monitoring
License:      GPL
Version:      5.35.0
Release:      20250410

#   package options
%option       with_fsl   yes
%option       with_ssl   no

#   list of sources
Source0:      http://mmonit.com/monit/dist/monit-%{version}.tar.gz
Source1:      rc.monit
Source2:      fsl.monit
Source3:      monitrc
Patch0:       monit.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, gcc, bison, flex
PreReq:       OpenPKG, openpkg >= 20160101
%if "%{with_fsl}" == "yes"
BuildPreReq:  fsl
PreReq:       fsl
%endif
%if "%{with_ssl}" == "yes"
BuildPreReq:  openssl
PreReq:       openssl
%endif

%description
    Monit is a utility for monitoring and managing daemons or similar
    programs running on a Unix system. It will start specified programs
    if they are not running and restart programs not responding.

%track
    prog monit = {
        version   = %{version}
        url       = http://mmonit.com/monit/dist/
        regex     = monit-(__VER__)\.tar\.gz
    }

%prep
    #   unpack and patch distribution
    %setup -q
    %patch -p0
    %{l_shtool} subst %{l_value -s -a} \
        src/file.c monit.1
    %{l_shtool} subst \
        -e 's;piddir=;dummy=;g' \
        configure

%build
    #   configure program
    cppflags=""
    libs=""
    options=""
    case "%{l_platform -t}" in
        *-sunos5.6 )
            cppflags="-Dsocklen_t=int"
            libs="-lkstat"
            ;;
        *-sunos* )
            options="--without-largefiles"
            ;;
    esac
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags} $cppflags" \
    LDFLAGS="%{l_ldflags} %{l_fsl_ldflags}" \
    LIBS="%{l_fsl_libs} $libs" \
    GREP="grep" \
    piddir="%{l_prefix}/var/monit" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
%if "%{with_ssl}" == "yes"
        --with-ssl \
        --with-ssl-dir=%{l_prefix} \
%else
        --without-ssl \
%endif
        $options

    #   build program
    %{l_make} %{l_mflags -O}

%install
    #   install program
    %{l_make} %{l_mflags} install \
        DESTDIR="$RPM_BUILD_ROOT" \
        INSTALL="%{l_shtool} install -c"

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.monit} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install default configuration
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/monit
    %{l_shtool} install -c -m 600 %{l_value -s -a} \
        %{SOURCE monitrc} $RPM_BUILD_ROOT%{l_prefix}/etc/monit/

    #   create empty run-time directory
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/monit

    #   install OSSP fsl configuration
    %{l_shtool} mkdir -f -p -m 755 $RPM_BUILD_ROOT%{l_prefix}/etc/fsl
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE fsl.monit} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/fsl/fsl.monit' \
        '%config %attr(0600,%{l_susr},%{l_mgrp}) %{l_prefix}/etc/monit/*'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} monit status 2>/dev/null`
    [ ".$monit_active" = .yes ] && %{l_rc} monit restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} monit stop 2>/dev/null
    rm -f $RPM_INSTALL_PREFIX/var/monit/*
    exit 0

